ArgsBuilder

Struct ArgsBuilder 

pub struct ArgsBuilder { /* private fields */ }
A type for passing arguments to Parasol programs. When invoking crate::FheComputer::run_program, the processor will transparently set up the registers and first stack frame according to Parasol ABI’s calling convention.

Remarks

Parasol’s calling convention is similar to x86’s cdecl. We first allocate stack space for storing all arguments and the return value as well as padding to maintain alignment requirements for each argument and the return value. Furthermore, the stack pointer must be 16-byte aligned after pushing all the call data. Arguments are stored in reverse order (i.e. the first argument appears at SP+0 while the second at SP+sizeof(arg1), and so-on), followed by the return value.

Parasol stacks grow downwards, while arguments and values within a frame grow upwards.

Implementations

Source

impl ArgsBuilder

pub fn new() -> Self

Create a new ArgsBuilder.

pub fn arg<T: ToArg>(self, val: T) -> Self

Add an argument

pub fn arg_dyn<T: DynamicToArg>(self, val: T) -> Self

Similar to ArgsBuilder::arg but the value is DynamicToArg

pub fn return_value<T: ToArg>(self) -> CallData<T>

Specify a return value for an FHE program.

pub fn return_value_dyn( self, align: usize, num_bytes: usize, ) -> CallData<Vec<Byte>>

Specify a return value for an FHE program using the alignment and size.

pub fn no_return_value(self) -> CallData<()>

Create the CallData object from this builder, ignoring any value the program returns (if any).